<?php

namespace Provider1\Aboutus\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Provider1\Aboutus\Http\Requests\QuoteRequest;
use Provider1\Aboutus\Interfaces\QuoteRepositoryInterface;
use Provider1\Aboutus\Models\Quote;

/**
 * Admin web controller class.
 */
class QuoteAdminController extends BaseController
{
    // use QuoteWorkflow;
    /**
     * Initialize quote controller.
     *
     * @param type QuoteRepositoryInterface $quote
     *
     * @return type
     */
    public function __construct(QuoteRepositoryInterface $quote)
    {
        $this->repository = $quote;
        parent::__construct();
    }

    /**
     * Display a list of quote.
     *
     * @return Response
     */
    public function index(QuoteRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('aboutus::quote.names').' :: ');
        return $this->theme->of('aboutus::admin.quote.index')->render();
    }

    /**
     * Display a list of quote.
     *
     * @return Response
     */
    public function getJson(QuoteRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $quotes  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Provider1\\Aboutus\\Repositories\\Presenter\\QuoteListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $quotes['recordsTotal']    = $quotes['meta']['pagination']['total'];
        $quotes['recordsFiltered'] = $quotes['meta']['pagination']['total'];
        $quotes['request']         = $request->all();
        return response()->json($quotes, 200);

    }

    /**
     * Display quote.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return Response
     */
    public function show(QuoteRequest $request, Quote $quote)
    {
        if (!$quote->exists) {
            return response()->view('aboutus::admin.quote.new', compact('quote'));
        }

        Form::populate($quote);
        return response()->view('aboutus::admin.quote.show', compact('quote'));
    }

    /**
     * Show the form for creating a new quote.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(QuoteRequest $request)
    {

        $quote = $this->repository->newInstance([]);

        Form::populate($quote);

        return response()->view('aboutus::admin.quote.create', compact('quote'));

    }

    /**
     * Create new quote.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(QuoteRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $quote          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('aboutus::quote.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/aboutus/quote/'.$quote->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show quote for editing.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return Response
     */
    public function edit(QuoteRequest $request, Quote $quote)
    {
        Form::populate($quote);
        return  response()->view('aboutus::admin.quote.edit', compact('quote'));
    }

    /**
     * Update the quote.
     *
     * @param Request $request
     * @param Model   $quote
     *
     * @return Response
     */
    public function update(QuoteRequest $request, Quote $quote)
    {
        try {

            $attributes = $request->all();

            $quote->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('aboutus::quote.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/aboutus/quote/'.$quote->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/aboutus/quote/'.$quote->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the quote.
     *
     * @param Model   $quote
     *
     * @return Response
     */
    public function destroy(QuoteRequest $request, Quote $quote)
    {

        try {

            $t = $quote->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('aboutus::quote.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/aboutus/quote/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/aboutus/quote/'.$quote->getRouteKey()),
            ], 400);
        }
    }

}
